``aladhan.py`` is an asynchronous pythonic wrapper for the Aladhan prayer times API.

Installation
------------

**Python 3.6 or higher is required.**

Install ``aladhan.py`` with pip:

.. code:: sh

    pip install aladhan.py

Contribute
----------

- `Source Code <https://github.com/HETHAT/aladhan.py>`_
- `Issue Tracker <https://github.com/HETHAT/aladhan.py/issues>`_


Support
-------

If you are having issues, please let me know by joining the `discord support server <https://discord.gg/mXaEuxYRan>`_

License
-------

The project is licensed under the MIT license.